@@ -1,5 +1,8 @@
 from captur_ml_sdk.utils.gcp_functions import (
-    get_requested_model_id, check_file_exists, get_model_type_from_gcp
+    get_requested_model_id, 
+    check_file_exists, 
+    get_model_type_from_gcp,
+    check_specific_version_exists
 )
 
 from captur_ml_sdk.dtypes.exceptions import (
@@ -28,6 +31,16 @@ def check_model_exists(cls, values):
     return values
 
 
+def check_model_exists_in_gcp(cls, values):
+    name = values.get("name")
+    version = values.get("version")
+    if not check_specific_version_exists(name, version):
+        raise TypeError(f"Model name: {name} version: {version}\
+                          does not exist in GCP ")
+    else:
+        return values
+
+
 def fetch_model_type(cls, values):
     name = values.get("name")
     try:
